@@ -2,7 +2,7 @@ from typing import Any
 
 from rodi import ContainerProtocol
 
-from injection import Module, default_module
+from injection import Module
 
 __all__ = ("InjectionServices",)
 
@@ -14,8 +14,8 @@ class InjectionServices(ContainerProtocol):
 
     __slots__ = ("__module",)
 
-    def __init__(self, module: Module = default_module):
-        self.__module = module
+    def __init__(self, module: Module = None):
+        self.__module = module or Module.default()
 
     def __contains__(self, item: Any) -> bool:
         return item in self.__module
